==> dnv_bladed_models-0.3.32.tar.gz: dnv_bladed_models-0.3.32/src/dnv_bladed_models/momentum_theory_corrections.py <==
# coding: utf-8

from __future__ import annotations
from datetime import date, datetime  # noqa: F401
from enum import Enum, IntEnum

import re  # noqa: F401
from typing import Any, Dict, List, Optional, Type, Union, Callable  # noqa: F401
from pathlib import Path
from typing import TypeVar
Model = TypeVar('Model', bound='BaseModel')
StrBytes = Union[str, bytes]

from pydantic import AnyUrl, BaseModel, EmailStr, Field, validator, root_validator, Extra  # noqa: F401

from dnv_bladed_models.dnv import Dnv

from dnv_bladed_models.dynamic_wake import DynamicWake

from dnv_bladed_models.glauert_skew_wake_model import GlauertSkewWakeModel


class MomentumTheoryCorrections_GlauertCorrectionMethodForHighInductionEnum(str, Enum):
    BLADED = "BLADED"
    NONE = "NONE"

class MomentumTheoryCorrections(Dnv):
    """MomentumTheoryCorrections - The Blade Element Momentum (BEM) theory model [https://www.wikipedia.org/wiki/Blade_element_momentum_theory].

    Attributes:
        - GlauertCorrectionMethodForHighInduction: MomentumTheoryCorrections_GlauertCorrectionMethodForHighInductionEnum => The Glauert correction method for when the rotor has high induction.
        - GlauertSkewedWakeCorrectionModel: GlauertSkewWakeModel 
        - InductionFactorsTolerance: float => A number representing a fraction, ratio, or other non-dimensionalised property.
        - NoInflowBelowTipSpeedRatio: float => A number representing a fraction, ratio, or other non-dimensionalised property.
        - FullInflowAboveTipSpeedRatio: float => A number representing a fraction, ratio, or other non-dimensionalised property.
        - DynamicWake: DynamicWake 
        - IncludeStructuralVelocityInInductionCalculation: bool => If true, the axial structural velocity will be included in the induction calculations. Enabled by default.
    """

    GlauertCorrectionMethodForHighInduction: Optional[MomentumTheoryCorrections_GlauertCorrectionMethodForHighInductionEnum] = Field(alias="GlauertCorrectionMethodForHighInduction", default='BLADED')
    GlauertSkewedWakeCorrectionModel: Optional[GlauertSkewWakeModel] = Field(alias="GlauertSkewedWakeCorrectionModel", default=None)
    InductionFactorsTolerance: Optional[float] = Field(alias="InductionFactorsTolerance", default=None)
    NoInflowBelowTipSpeedRatio: Optional[float] = Field(alias="NoInflowBelowTipSpeedRatio", default=None)
    FullInflowAboveTipSpeedRatio: Optional[float] = Field(alias="FullInflowAboveTipSpeedRatio", default=None)
    DynamicWake: Optional[DynamicWake] = Field(alias="DynamicWake", default=None)
    IncludeStructuralVelocityInInductionCalculation: Optional[bool] = Field(alias="IncludeStructuralVelocityInInductionCalculation", default=True)

    class Config:
        extra = Extra.forbid
        validate_assignment = True
        allow_population_by_field_name = True
        pass

    @root_validator(pre=True)
    def parsing_ignores_underscore_properties(cls, values: dict[str, any]):
        allowed_vals = {}
        for key, val in values.items():
            if not key.startswith('_'):
                if isinstance(val, dict):
                    allowed_child_vals = {}
                    for child_key, child_val in val.items():
                        if not child_key.startswith('_'):
                            allowed_child_vals[child_key] = child_val
                    allowed_vals[key] = allowed_child_vals
                else:
                    allowed_vals[key] = val
        return allowed_vals

    def to_json(
        self,
        *, 
        include: Optional[Union['AbstractSetIntStr', 'MappingIntStrAny']] = None, 
        exclude: Optional[Union['AbstractSetIntStr', 'MappingIntStrAny']] = None, 
        by_alias: bool = True, 
        skip_defaults: Optional[bool] = None, 
        exclude_unset: bool = False, 
        exclude_defaults: bool = False, 
        exclude_none: bool = True, 
        encoder: Optional[Callable[[Any], Any]] = None, 
        models_as_dict: bool = True, 
        **dumps_kwargs: Any) -> str:

        r"""
        Generates a JSON string representation of the model.
        
        Notes
        -----
        `include` and `exclude` arguments as per `dict()`.

        `encoder` is an optional function to supply as `default` to json.dumps(), other arguments as per `json.dumps()`.

        Examples
        --------
        >>> model.to_json()

        Renders the full JSON representation of the model object.
        """

        if dumps_kwargs.get('indent') is None:
            dumps_kwargs.update(indent=2)

        return super().json(
                include=include, 
                exclude=exclude, 
                by_alias=by_alias, 
                skip_defaults=skip_defaults, 
                exclude_unset=exclude_unset, 
                exclude_defaults=exclude_defaults, 
                exclude_none=exclude_none, 
                encoder=encoder, 
                models_as_dict=models_as_dict, 
                **dumps_kwargs)
    
    @classmethod
    def from_file(
        cls: Type['Model'],
        path: Union[str, Path]) -> 'Model':
        
        r"""
        Loads a model from a given file path.

        Parameters
        ----------
        path : string
            The file path to the model.

        Returns
        -------
        MomentumTheoryCorrections
            The model object.

        Raises
        ------
        ValueError, ValidationError
            If the JSON document does not correctly describe the model according to the model schema.

        Examples
        --------
        >>> model = MomentumTheoryCorrections.from_file('/path/to/file')
        """
        
        return super().parse_file(path=path)
    
    @classmethod
    def from_json(
        cls: Type['Model'],
        b: StrBytes) -> 'Model':

        r"""
        Creates a model object from a JSON string.

        Parameters
        ----------
        b: StrBytes
            The JSON string describing the model.

        Returns
        -------
        MomentumTheoryCorrections
            The model object.

        Raises
        ------
        ValueError, ValidationError
            If the JSON document does not correctly describe the model according to the model schema.

        Examples
        --------
        >>> model = MomentumTheoryCorrections.from_json('{ ... }')
        """

        return super().parse_raw(
            b=b,
            content_type='application/json')
    
    @classmethod
    def from_dict(
        cls: Type['Model'],
         obj: Any) -> 'Model':

        r"""
        Creates a model object from a dict.

        Parameters
        ----------
        obj : Any
            The dictionary object describing the model.

        Returns
        -------
        MomentumTheoryCorrections
            The model object.

        Raises
        ------
        ValueError, ValidationError
            If the JSON document does not correctly describe the model according to the model schema.
        """
        
        return super().parse_obj(obj=obj)
    
    def to_file(
        self,
        path: Union[str, Path]):

        r"""
        Writes the model as a JSON document to a file with UTF8 encoding.        

        Parameters
        ----------                
        path : string
            The file path to which the model will be written.

        Examples
        --------
        >>> model.to_file('/path/to/file')

        """

        with open(file=path, mode='w', encoding="utf8") as output_file:
            output_file.write(self.to_json())

MomentumTheoryCorrections.update_forward_refs()

==> dnv_bladed_models-0.3.44.tar.gz: dnv_bladed_models-0.3.44/src/dnv_bladed_models/momentum_theory_corrections.py <==
# coding: utf-8

from __future__ import annotations
from datetime import date, datetime  # noqa: F401
from enum import Enum, IntEnum

import re  # noqa: F401
from typing import Any, Dict, List, Optional, Type, Union, Callable  # noqa: F401
from pathlib import Path
from typing import TypeVar
Model = TypeVar('Model', bound='BaseModel')
StrBytes = Union[str, bytes]

from pydantic import AnyUrl, BaseModel, EmailStr, Field, validator, root_validator, Extra  # noqa: F401


from dnv_bladed_models.dnv import Dnv

from dnv_bladed_models.dynamic_wake import DynamicWake

from dnv_bladed_models.glauert_skew_wake_model import GlauertSkewWakeModel


class MomentumTheoryCorrections_GlauertCorrectionMethodForHighInductionEnum(str, Enum):
    BLADED = "BLADED"
    NONE = "NONE"

class MomentumTheoryCorrections(Dnv):
    """MomentumTheoryCorrections - The Blade Element Momentum (BEM) theory model [https://www.wikipedia.org/wiki/Blade_element_momentum_theory].
    
    Attributes:
    ----------
    GlauertCorrectionMethodForHighInduction : MomentumTheoryCorrections_GlauertCorrectionMethodForHighInductionEnum, default='BLADED'
        The Glauert correction method for when the rotor has high induction.
    GlauertSkewedWakeCorrectionModel : GlauertSkewWakeModel
    InductionFactorsTolerance : float
        A number representing a fraction, ratio, or other non-dimensionalised property.
    NoInflowBelowTipSpeedRatio : float
        A number representing a fraction, ratio, or other non-dimensionalised property.
    FullInflowAboveTipSpeedRatio : float
        A number representing a fraction, ratio, or other non-dimensionalised property.
    DynamicWake : DynamicWake, abstract
    IncludeStructuralVelocityInInductionCalculation : bool, default=True
        If true, the axial structural velocity will be included in the induction calculations. Enabled by default.
    
    Notes:
    ---------
    DynamicWake has the following concrete types:
        - EquilibriumWakeModel
        - FreeFlowModel
        - FrozenWakeModel
        - OyeDynamicWake
        - PittAndPetersModel
    
    """

    GlauertCorrectionMethodForHighInduction: Optional[MomentumTheoryCorrections_GlauertCorrectionMethodForHighInductionEnum] = Field(alias="GlauertCorrectionMethodForHighInduction", default='BLADED')
    GlauertSkewedWakeCorrectionModel: Optional[GlauertSkewWakeModel] = Field(alias="GlauertSkewedWakeCorrectionModel", default=None)
    InductionFactorsTolerance: Optional[float] = Field(alias="InductionFactorsTolerance", default=None)
    NoInflowBelowTipSpeedRatio: Optional[float] = Field(alias="NoInflowBelowTipSpeedRatio", default=None)
    FullInflowAboveTipSpeedRatio: Optional[float] = Field(alias="FullInflowAboveTipSpeedRatio", default=None)
    DynamicWake: Optional[DynamicWake] = Field(alias="DynamicWake", default=None)
    IncludeStructuralVelocityInInductionCalculation: Optional[bool] = Field(alias="IncludeStructuralVelocityInInductionCalculation", default=True)

    class Config:
        extra = Extra.forbid
        validate_assignment = True
        allow_population_by_field_name = True
        pass

    @root_validator(pre=True)
    def _parsing_ignores_underscore_properties(cls, values: dict[str, any]):
        allowed_vals = {}
        for key, val in values.items():
            if not key.startswith('_'):
                if isinstance(val, dict):
                    allowed_child_vals = {}
                    for child_key, child_val in val.items():
                        if not child_key.startswith('_'):
                            allowed_child_vals[child_key] = child_val
                    allowed_vals[key] = allowed_child_vals
                else:
                    allowed_vals[key] = val
        return allowed_vals

    def to_json(
        self,
        *, 
        include: Optional[Union['AbstractSetIntStr', 'MappingIntStrAny']] = None, 
        exclude: Optional[Union['AbstractSetIntStr', 'MappingIntStrAny']] = None, 
        by_alias: bool = True, 
        skip_defaults: Optional[bool] = None, 
        exclude_unset: bool = False, 
        exclude_defaults: bool = False, 
        exclude_none: bool = True, 
        encoder: Optional[Callable[[Any], Any]] = None, 
        models_as_dict: bool = True, 
        **dumps_kwargs: Any) -> str:

        r"""
        Generates a JSON string representation of the model.
        
        Notes
        -----
        `include` and `exclude` arguments as per `dict()`.

        `encoder` is an optional function to supply as `default` to json.dumps(), other arguments as per `json.dumps()`.

        Examples
        --------
        >>> model.to_json()

        Renders the full JSON representation of the model object.
        """

        if dumps_kwargs.get('indent') is None:
            dumps_kwargs.update(indent=2)

        return super().json(
                include=include, 
                exclude=exclude, 
                by_alias=by_alias, 
                skip_defaults=skip_defaults, 
                exclude_unset=exclude_unset, 
                exclude_defaults=exclude_defaults, 
                exclude_none=exclude_none, 
                encoder=encoder, 
                models_as_dict=models_as_dict, 
                **dumps_kwargs)
    
    @classmethod
    def from_file(
        cls: Type['Model'],
        path: Union[str, Path]) -> 'Model':
        
        r"""
        Loads a model from a given file path.

        Parameters
        ----------
        path : string
            The file path to the model.

        Returns
        -------
        MomentumTheoryCorrections
            The model object.

        Raises
        ------
        ValueError, ValidationError
            If the JSON document does not correctly describe the model according to the model schema.

        Examples
        --------
        >>> model = MomentumTheoryCorrections.from_file('/path/to/file')
        """
        
        return super().parse_file(path=path)
    
    @classmethod
    def from_json(
        cls: Type['Model'],
        b: StrBytes) -> 'Model':

        r"""
        Creates a model object from a JSON string.

        Parameters
        ----------
        b: StrBytes
            The JSON string describing the model.

        Returns
        -------
        MomentumTheoryCorrections
            The model object.

        Raises
        ------
        ValueError, ValidationError
            If the JSON document does not correctly describe the model according to the model schema.

        Examples
        --------
        >>> model = MomentumTheoryCorrections.from_json('{ ... }')
        """

        return super().parse_raw(
            b=b,
            content_type='application/json')
    
    @classmethod
    def from_dict(
        cls: Type['Model'],
         obj: Any) -> 'Model':

        r"""
        Creates a model object from a dict.

        Parameters
        ----------
        obj : Any
            The dictionary object describing the model.

        Returns
        -------
        MomentumTheoryCorrections
            The model object.

        Raises
        ------
        ValueError, ValidationError
            If the JSON document does not correctly describe the model according to the model schema.
        """
        
        return super().parse_obj(obj=obj)
    
    def to_file(
        self,
        path: Union[str, Path]):

        r"""
        Writes the model as a JSON document to a file with UTF8 encoding.        

        Parameters
        ----------                
        path : string
            The file path to which the model will be written.

        Examples
        --------
        >>> model.to_file('/path/to/file')

        """

        with open(file=path, mode='w', encoding="utf8") as output_file:
            output_file.write(self.to_json())

MomentumTheoryCorrections.update_forward_refs()
